==> senior_platform_authentication_ui-0.0.1.tar.gz: README.md <==
# Senior Platform Authentication Ui
O objetivo deste projeto é prover uma experiência única de autenticação com aplicativos integrados a Senior X. Este pacote utilizar o pacote em dart senior_platform_authentication que fornece uma integração já implementada ao backend de autenticação do Senior X. 

Sendo assim, para manter a integridade da experiência de autenticação, é importante que aplicativos que necessitem de autenticação com a plataforma Senior-X tenham dependência deste pacote. Caso seja necessário alguma adaptação ou customização maior no fluxo de autenticação, pode-se utilizar o pacote senior_platform_authentication e implementar as regras de forma manual ou contribuir com este pacote para adicionar os casos de usos necessários.

## Arquitetura
A arquitetura foi baseada no Clean Architecture, entretanto com algumas adaptações para o escopo do projeto após análise técnica da equipe responsável pelo desenvolvimento incicial deste projeto.

![Diagrama da arquitetura definida](./images/login_flutter_architecture.jpg)

## Como utilizar
Carregue o pacote senior_platform_authentication_ui.
```dart
import 'package:senior_platform_authentication_ui/senior_platform_authentication_ui.dart';
```

É obrigatório que a classe principal seja inicializada na main thread de sua aplicação.
```dart
SeniorAuthentication.initialize(
  enableLoginOffline: false,
  url: '{BASE_URL}',
);
```

Coloque um BlocProvider na raiz da aplicação Flutter. Deste modo, poderá ter acesso ao estado da autenticação a qualquer momento do ciclo de vida de seu aplicativo.

**Obs: É extremamente recomendável colocar o componente base do Design System (SeniorDesignSystem) no primeiro nível e logo abaixo dele o BlocProvider. O pacote senior_platform_authentication_ui foi construído com dependência do Design System da Senior.

```dart
class ExampleApp extends StatelessWidget {
  const ExampleApp({super.key});

  @override
  Widget build(BuildContext context) {
    return SeniorDesignSystem(
      child: BlocProvider(
        create: (context) =>
            AuthenticationBloc.leaf()..add(CheckAuthenticationRequested()),
        child: const AppView(),
      ),
    );
  }
}
```

É importante ressaltar que, o AuthenticationBloc em todos construtores disponíveis, funciona como um singleton. Logo fique atento a forma com que irá utilizá-lo para evitar problemas.

Podemos construir o AuthenticationBloc das seguintes maneiras também:

```dart
...
    BlocProvider(
        create: (context) =>
            AuthenticationBloc.homolog(),
        child: const AppView(),
    ),
...

```

```dart
...
    BlocProvider(
        create: (context) =>
            AuthenticationBloc.production(),
        child: const AppView(),
    ),
...

```

```dart
...
    BlocProvider(
        create: (context) =>
            AuthenticationBloc(SeniorEnvironment.leaf),
        child: const AppView(),
    ),
...

```

Recomendamos utilizar a seguinte abordagem para controle de rotas conforme o status da autenticação:

```dart
class AppView extends StatefulWidget {
  const AppView({super.key});

  @override
  State<AppView> createState() => _AppViewState();
}

class _AppViewState extends State<AppView> {
  final _navigatorKey = GlobalKey<NavigatorState>();

  NavigatorState get _navigator => _navigatorKey.currentState!;

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      navigatorKey: _navigatorKey,
      builder: (context, child) {
        return BlocListener<AuthenticationBloc, AuthenticationState>(
          listener: (context, state) {
            switch (state.status) {
              case AuthenticationStatus.authenticated:
                _navigator.pushAndRemoveUntil<void>(
                  MaterialPageRoute<void>(builder: (_) => const HomeScreen()),
                  (route) => false,
                );
                break;
              case AuthenticationStatus.unauthenticated:
                _navigator.pushAndRemoveUntil<void>(
                  MaterialPageRoute<void>(
                    builder: (_) => const LoginScreen(),
                  ),
                  (route) => false,
                );
                break;
              case AuthenticationStatus.unknown:
                break;
            }
          },
          child: child,
        );
      },
      onGenerateRoute: (_) => SplashScreen.route(),
    );
  }
}
```

## Como contribuir
Para contribuir, basta abrir um Merge Request para algum dos mantedores do projeto seguindos as boas práticas acordadas nas seções abaixo.

### Cobertura de testes
Entendemos que para manter a qualidade e integridade do código, é exigido uma cobertura de testes de pelo menos 80% para o que foi desenvolvido. Nossa sugestão é utilizar as extensões Coverage Gutters e Flutter Coverage para desenvolvimento dos testes.

### Formatação de código
Já está incluído um arquivo de configuração com as configurações de identação do projeto, por padrão utilizamos o reocmendável do SDK (80). Por favor, não modificar e seguir este padrão.

### Modificando arquivos .arb (Internacionalização)
to sync l10n translations use the following command after modifiyng the .arb files:
```
flutter gen-l10n --arb-dir l10n --template-arb-file app_en.arb --output-localization-file app_localizations.dart --output-dir lib/src/core/l10n/.gen --no-synthetic-package
```

### Armazenar dados locais
Utilizamos o package flutter_secure_storage para armazenamento de dados locais. Existem hoje dois local datasources para armazenagem, o SecureStorageDatasource e o PreferencesStorageDatasource. O primeiro possui como objetivo armazenar apenas dados referentes a autenticação, como token, expiração e usuário por exemplo. O segundo serve para armazenar preferencias do usuário, como por exemplo se a mensagem do onboarding do SAML está habilitada.

Caso seja necessário armazenar mais dados no futuro, cabe ao desenvolvedor avaliar o contexto se é algo de preferências do usuário, utilizar o PreferencesStorageDatasource. Caso seja relacionado a algum dado sensível da autenticação, utilizar o SecureStorageDatasource.

==> senior_platform_authentication_ui-0.0.2.tar.gz: README.md <==
# Senior Platform Authentication Ui
O objetivo deste projeto é prover uma experiência única de autenticação com aplicativos integrados a Senior X. Este pacote utilizar o pacote em dart senior_platform_authentication que fornece uma integração já implementada ao backend de autenticação do Senior X. 

Sendo assim, para manter a integridade da experiência de autenticação, é importante que aplicativos que necessitem de autenticação com a plataforma Senior-X tenham dependência deste pacote. Caso seja necessário alguma adaptação ou customização maior no fluxo de autenticação, pode-se utilizar o pacote senior_platform_authentication e implementar as regras de forma manual ou contribuir com este pacote para adicionar os casos de usos necessários.

## Arquitetura
A arquitetura foi baseada no Clean Architecture, entretanto com algumas adaptações para o escopo do projeto após análise técnica da equipe responsável pelo desenvolvimento incicial deste projeto.

![Diagrama da arquitetura definida](./images/login_flutter_architecture.jpg)

## Como utilizar
Carregue o pacote senior_platform_authentication_ui.
```dart
import 'package:senior_platform_authentication_ui/senior_platform_authentication_ui.dart';
```

É obrigatório que a classe principal seja inicializada na main thread de sua aplicação.
```dart
SeniorAuthentication.initialize(
  enableLoginOffline: false,
  url: '{BASE_URL}',
);
```

Coloque um BlocProvider na raiz da aplicação Flutter. Deste modo, poderá ter acesso ao estado da autenticação a qualquer momento do ciclo de vida de seu aplicativo.

**Obs: É extremamente recomendável colocar o componente base do Design System (SeniorDesignSystem) no primeiro nível e logo abaixo dele o BlocProvider. O pacote senior_platform_authentication_ui foi construído com dependência do Design System da Senior.

```dart
class ExampleApp extends StatelessWidget {
  const ExampleApp({super.key});

  @override
  Widget build(BuildContext context) {
    return SeniorDesignSystem(
      child: BlocProvider(
        create: (context) =>
            AuthenticationBloc()..add(CheckAuthenticationRequested()),
        child: const AppView(),
      ),
    );
  }
}
```

É importante ressaltar que, o AuthenticationBloc em todos construtores disponíveis, funciona como um singleton. Logo fique atento a forma com que irá utilizá-lo para evitar problemas.

Recomendamos utilizar a seguinte abordagem para controle de rotas conforme o status da autenticação:

```dart
class AppView extends StatefulWidget {
  const AppView({super.key});

  @override
  State<AppView> createState() => _AppViewState();
}

class _AppViewState extends State<AppView> {
  final _navigatorKey = GlobalKey<NavigatorState>();

  NavigatorState get _navigator => _navigatorKey.currentState!;

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      navigatorKey: _navigatorKey,
      builder: (context, child) {
        return BlocListener<AuthenticationBloc, AuthenticationState>(
          listener: (context, state) {
            switch (state.status) {
              case AuthenticationStatus.authenticated:
                _navigator.pushAndRemoveUntil<void>(
                  MaterialPageRoute<void>(builder: (_) => const HomeScreen()),
                  (route) => false,
                );
                break;
              case AuthenticationStatus.unauthenticated:
                _navigator.pushAndRemoveUntil<void>(
                  MaterialPageRoute<void>(
                    builder: (_) => const LoginScreen(),
                  ),
                  (route) => false,
                );
                break;
              case AuthenticationStatus.unknown:
                break;
            }
          },
          child: child,
        );
      },
      onGenerateRoute: (_) => SplashScreen.route(),
    );
  }
}
```

## Como contribuir
Para contribuir, basta abrir um Merge Request para algum dos mantedores do projeto seguindos as boas práticas acordadas nas seções abaixo.

### Cobertura de testes
Entendemos que para manter a qualidade e integridade do código, é exigido uma cobertura de testes de pelo menos 80% para o que foi desenvolvido. Nossa sugestão é utilizar as extensões Coverage Gutters e Flutter Coverage para desenvolvimento dos testes.

### Formatação de código
Já está incluído um arquivo de configuração com as configurações de identação do projeto, por padrão utilizamos o reocmendável do SDK (80). Por favor, não modificar e seguir este padrão.

### Modificando arquivos .arb (Internacionalização)
to sync l10n translations use the following command after modifiyng the .arb files:
```
flutter gen-l10n --arb-dir l10n --template-arb-file app_en.arb --output-localization-file app_localizations.dart --output-dir lib/src/core/l10n/.gen --no-synthetic-package
```

### Armazenar dados locais
Utilizamos o package flutter_secure_storage para armazenamento de dados locais. Existem hoje dois local datasources para armazenagem, o SecureStorageDatasource e o PreferencesStorageDatasource. O primeiro possui como objetivo armazenar apenas dados referentes a autenticação, como token, expiração e usuário por exemplo. O segundo serve para armazenar preferencias do usuário, como por exemplo se a mensagem do onboarding do SAML está habilitada.

Caso seja necessário armazenar mais dados no futuro, cabe ao desenvolvedor avaliar o contexto se é algo de preferências do usuário, utilizar o PreferencesStorageDatasource. Caso seja relacionado a algum dado sensível da autenticação, utilizar o SecureStorageDatasource.
